==> currents-api-types-0.0.35.tgz: package/books/constants.ts <==
export const BOOK_PAYINS_AUTHOR = 'payins.author' as const;
export const BOOK_PAYOUTS_AUTHOR = 'payouts.author' as const;
export const BOOK_REFUNDS_AUTHOR = 'refunds.author' as const;
export const BOOK_PENDING_AUTHOR = 'pending.author' as const;
// blocked by the system before an attempt to pay out thru external system
export const BOOK_BLOCKED_AUTHOR = 'queued.author' as const;
export const BOOK_PAYINS_ENJOYER = 'payins.enjoyer' as const;
export const BOOK_PAYOUTS_ENJOYER = 'payouts.enjoyer' as const;
export const BOOK_REFUNDS_ENJOYER = 'refunds.enjoyer' as const;
export const BOOK_PENDING_ENJOYER = 'pending.enjoyer' as const;
export const BOOK_TYPES = [
  BOOK_PAYINS_AUTHOR,
  BOOK_REFUNDS_AUTHOR,
  BOOK_PENDING_AUTHOR,
  BOOK_PAYOUTS_AUTHOR,
  BOOK_BLOCKED_AUTHOR,
  BOOK_PAYINS_ENJOYER,
  BOOK_PAYOUTS_ENJOYER,
  BOOK_REFUNDS_ENJOYER,
  BOOK_PENDING_ENJOYER,
];
export const BOOK_OP_DEBIT = 'debit' as const;
export const BOOK_OP_CREDIT = 'credit' as const;
export const BOOK_OPS = [BOOK_OP_DEBIT, BOOK_OP_CREDIT] as const; // we operate only on assets and liabilities;
// a "place" naming is from Closure language and means a "mutable entity" which is book (account) in our case
export const PLACE_KINDS = ['asset', 'liability'] as const;
export const PLACE_OPERATION = ['increase', 'decrease'] as const;

/* these types involved in reactions to external events; they're indicators or what happens in the real world */
export const BOOK_TYPES_REACTIVE = [
  BOOK_REFUNDS_AUTHOR,
  BOOK_PAYOUTS_AUTHOR,
  BOOK_PAYINS_ENJOYER,
  BOOK_REFUNDS_ENJOYER,
] as const;

export const BOOKS_TYPES_NEGATEABLE = BOOK_TYPES_REACTIVE;
export const BOOKS_TYPES_NEGATEABLE_S = new Set(BOOKS_TYPES_NEGATEABLE);

==> currents-api-types-0.0.42.tgz: package/books/constants.ts <==
export const BOOK_PAYINS_AUTHOR = 'payins.author' as const;
export const BOOK_PAYOUTS_AUTHOR = 'payouts.author' as const;
export const BOOK_REFUNDS_AUTHOR = 'refunds.author' as const;
// whatever was taken from them by force - i.e. an Enjoyer called a refund
export const BOOK_DEPRIVATIONS_AUTHOR = 'deprivations.author' as const;
export const BOOK_PENDING_AUTHOR = 'pending.author' as const;
// blocked by the system before an attempt to pay out thru external system
export const BOOK_QUEUED_AUTHOR = 'queued.author' as const;
export const BOOK_PAYINS_ENJOYER = 'payins.enjoyer' as const;
export const BOOK_PAYOUTS_ENJOYER = 'payouts.enjoyer' as const;
export const BOOK_REFUNDS_ENJOYER = 'refunds.enjoyer' as const;
export const BOOK_PENDING_ENJOYER = 'pending.enjoyer' as const;
export const BOOK_TYPES = [
  BOOK_PAYINS_AUTHOR,
  BOOK_REFUNDS_AUTHOR,
  BOOK_PENDING_AUTHOR,
  BOOK_PAYOUTS_AUTHOR,
  BOOK_QUEUED_AUTHOR,
  BOOK_DEPRIVATIONS_AUTHOR,
  BOOK_PAYINS_ENJOYER,
  BOOK_PAYOUTS_ENJOYER,
  BOOK_REFUNDS_ENJOYER,
  BOOK_PENDING_ENJOYER,
];
export const BOOK_OP_DEBIT = 'debit' as const;
export const BOOK_OP_CREDIT = 'credit' as const;
export const BOOK_OPS = [BOOK_OP_DEBIT, BOOK_OP_CREDIT] as const; // we operate only on assets and liabilities;
// a "place" naming is from Closure language and means a "mutable entity" which is book (account) in our case
export const PLACE_KINDS = ['asset', 'liability'] as const;
export const PLACE_OPERATION = ['increase', 'decrease'] as const;

/* these types involved in reactions to external events; they're indicators or what happens in the real world */
export const BOOK_TYPES_REACTIVE = [
  BOOK_REFUNDS_AUTHOR,
  BOOK_PAYOUTS_AUTHOR,
  BOOK_PAYINS_ENJOYER,
  BOOK_REFUNDS_ENJOYER,
  BOOK_DEPRIVATIONS_AUTHOR,
] as const;

export const BOOKS_TYPES_NEGATEABLE = BOOK_TYPES_REACTIVE;
export const BOOKS_TYPES_NEGATEABLE_S = new Set(BOOKS_TYPES_NEGATEABLE);
